<template>
  <div>
    <el-form ref="loginForm"
             :model="loginForm"
             :rules="loginRules"
             class="login-form"
             label-width="0"
             status-icon
    >

      <el-form-item prop="selectInput">
        <el-select v-model="loginForm.value" placeholder="请选择组织" style="width: 326px" @change="selectchange">
          <i slot="prefix" class="el-icon-s-operation"/>
          <el-option
            v-for="(item,index) in loginForm.region"
            :key="index"
            :label="item.TENANT_NAME"
            :value="item.TENANT_ID">
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item prop="username">
        <el-input v-model="loginForm.username"
                  :placeholder="$t('login.username')"
                  auto-complete="off"
                  size="small"
                  @keyup.enter.native="handleLogin">
          <i slot="prefix" class="icon-yonghu"/>
        </el-input>
      </el-form-item>
      <el-form-item prop="password">
        <el-input v-model="loginForm.password"
                  :placeholder="$t('login.password')"
                  :type="passwordType"
                  auto-complete="off"
                  size="small"
                  @keyup.enter.native="handleLogin">
          <i slot="suffix" class="el-icon-view el-input__icon" @click="showPassword"/>
          <i slot="prefix" class="icon-mima"/>
        </el-input>
      </el-form-item>

      <el-form-item>
        <el-button class="login-submit"
                   size="small"
                   type="primary"
                   @click.native.prevent="handleLogin">{{ $t('login.submit') }}
        </el-button>
      </el-form-item>
      <!--密码修改弹出框-->
    </el-form>
    <el-dialog title="修改密码" :visible.sync="dialogFormVisible" append-to-body  >
      <el-form :model="form"  :rules="rules">
        <el-form-item label="原密码" :label-width="formLabelWidth" prop="oldname">
          <el-input v-model="form.oldPassword" autocomplete="off"></el-input>
        </el-form-item>
        <el-form-item label="新密码" :label-width="formLabelWidth" prop="newname">
          <el-input v-model="form.newPassword" autocomplete="off"></el-input>
        </el-form-item>
        <el-form-item label="确认密码" :label-width="formLabelWidth" prop="newname1">
          <el-input v-model="form.newPassword1" autocomplete="off"></el-input>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="dialogFormVisible = false">取 消</el-button>
        <el-button type="primary" @click="addok">确 定</el-button>
      </div>
    </el-dialog>
  </div>


</template>

<script>
import {mapGetters} from "vuex";
import {info} from "@/api/system/tenant";
import {getTopUrl} from "@/util/util";
import {updatePassword} from "@/api/system/user.js"
import md5 from "js-md5";
export default {
  name: "userlogin",
  data() {
    return {
      tenantMode: this.website.tenantMode,
      ButtonList: [],
      dialogFormVisible:false,
      form: {
        oldPassword: '',
        newPassword: '',
        newPassword1: '',
      },
      rules: {
        oldname: [
          { required: true, message: '请输入原密码', trigger: 'blur' }
        ],
        newname:[
          { required: true, message: '请输入新密码', trigger: 'blur' }
        ],
        newname1:[
          { required: true, message: '请输确认密码', trigger: 'blur' }
        ]
      },
      loginForm: {
        //租户ID
        tenantId: "000000",
        //部门ID
        deptId: "",
        //角色ID
        roleId: "",
        //用户名
        username: "admin",
        //密码
        password: "admin",
        selectInput: '',
        //下拉input数据
        value: '管理组',
        //下拉菜单
        region: [],
        //账号类型
        type: "account",
        //验证码的索引
        key: "",
        //预加载白色背景
        image: "data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7",

      },
      value: {
        selectInput: [
          {required: true, message: "请选择组织", trigger: "blur"}
        ],
        username: [
          {required: true, message: "请输入用户名", trigger: "blur"}
        ],
        password: [
          {required: true, message: "请输入密码", trigger: "blur"},
          {min: 1, message: "密码长度最少为6位", trigger: "blur"}
        ]
      },
      passwordType: "password",
      userBox: false,
      userForm: {
        deptId: '',
        roleId: ''
      },
      userinfo: []
    };
  },
  created() {
    this.getTenant();
  },
  mounted() {
    //在mounted获取首页下拉菜单数据
    this.$axios.get('/api/blade-system/tenant/tenant-map').then(res => {
      if (res.data.code == 200) {
        this.loginForm.region = res.data.data
      }
    })
  },
  watch: {
    'loginForm.deptId'() {
      const column = this.findObject(this.userOption.column, "deptId");
      if (this.loginForm.deptId.includes(",")) {
        column.dicUrl = `/api/blade-system/dept/select?deptId=${this.loginForm.deptId}`;
        column.display = true;
      } else {
        column.dicUrl = '';
      }
    },
    'loginForm.roleId'() {
      const column = this.findObject(this.userOption.column, "roleId");
      if (this.loginForm.roleId.includes(",")) {
        column.dicUrl = `/api/blade-system/role/select?roleId=${this.loginForm.roleId}`;
        column.display = true;
      } else {
        column.dicUrl = '';
      }
    }
  },
  computed: {
    ...mapGetters(["tagWel", "userInfo"])
  },
  props: [],
  methods: {
    addok(){
      this.dialogFormVisible = false
      updatePassword(md5(this.form.oldPassword), this.form.newPassword, this.form.newPassword1).then(res=>{
        if(res.data.code==200){
          this.$message({
            type:"success",
            message:"修改成功！"
          })

          this.$router.push({path: this.tagWel.value})
        }
      })
    },
    // 绑定下拉菜单动态ID
    selectchange(value) {
      this.loginForm.tenantId = value
      console.log(this.loginForm.tenantId)
    },
    showPassword() {
      this.passwordType === ""
        ? (this.passwordType = "password")
        : (this.passwordType = "");
    },
    submitLogin(form, done) {
      if (form.deptId !== '') {
        this.loginForm.deptId = form.deptId;
      }
      if (form.roleId !== '') {
        this.loginForm.roleId = form.roleId;
      }
      this.handleLogin();
      done();

    },
    handleLogin: function () {
      this.userInfo = this.$store.state.upadatastatus
      this.$refs.loginForm.validate(valid => {
        if (valid) {
          const loading = this.$loading({
            lock: true,
            text: '登录中,请稍后。。。',
            spinner: "el-icon-loading"
          });
          this.$store.dispatch("LoginByUsername", this.loginForm).then(() => {
            if (this.userInfo.strategyUpdateStatus != 0) {
              if (this.website.switchMode) {
                const deptId = this.userInfo.dept_id;
                const roleId = this.userInfo.role_id;
                if (deptId.includes(",") || roleId.includes(",")) {
                  this.loginForm.deptId = deptId;
                  this.loginForm.roleId = roleId;
                  this.userBox = true;
                  this.$store.dispatch("LogOut").then(() => {
                    loading.close();
                  });
                }
                return false
              }
              this.$router.push({path: this.tagWel.value});
            } else {
              this.$message({
                type: "warning",
                message: "密码策略已被修改，请重新修改密码！"
              })
             setTimeout(()=>{
               this.dialogFormVisible=true
             },1500)
            }
            console.log(this.userInfo)

            loading.close();
          }).catch(() => {
            loading.close();

          });
        }
      });
    },
    getTenant() {
      let domain = getTopUrl();
      // 临时指定域名，方便测试
      //domain = "https://bladex.vip";
      info(domain).then(res => {
        const data = res.data;
        if (data.success && data.data.tenantId) {
          this.tenantMode = false;
          this.loginForm.tenantId = data.data.tenantId;
          this.$parent.$refs.login.style.backgroundImage = `url(${data.data.backgroundUrl})`;
        }
      })
    }
  }
};
</script>

<style>
</style>
